@@ -2,27 +2,33 @@
 #'
 #' Export meshes to PLY-files (binary or ascii)
 #'
-#' @param mesh triangular mesh of class 'mesh3d'
+#' @param mesh triangular mesh of class 'mesh3d' or a numeric matrix with 3-columns
 #' @param filename character: filename (file extension '.ply' will be added automatically.
 #' @param binary logical: write binary file
 #' @param addNormals logical: compute per-vertex normals and add to file
 #' @param writeCol logical: export existing per-vertex color stored in mesh$material$color
+#' @param \dots additional arguments, currently not used.
 #' @examples
 #' data(humface)
 #' vcgPlyWrite(humface,filename = "humface")
-#' @export vcgPlyWrite
-vcgPlyWrite <- function(mesh, filename=dataname, binary = TRUE, addNormals = FALSE, writeCol=TRUE)
+#' @rdname vcgPlyWrite
+#' @export 
+vcgPlyWrite <- function(mesh, filename, binary = TRUE, ...) UseMethod("vcgPlyWrite")
+
+#' @rdname vcgPlyWrite
+#' @export
+vcgPlyWrite.mesh3d <- function(mesh, filename=dataname, binary = TRUE, addNormals = FALSE, writeCol=TRUE,...)
 {
     hasCol <- FALSE
     colvec <- matrix(0)
-    vb <- mesh$vb[1:3,]
+    vb <- mesh$vb[1:3,,drop=FALSE]
     if (!is.matrix(vb))
         stop("mesh has no vertices to write")
     it <- (mesh$it-1)
     dataname <- deparse(substitute(mesh))
     filename <- path.expand(as.character(filename))
     storage.mode(it) <- "integer"
-     if ( FALSE %in% is.integer(c(it)) || FALSE %in% is.numeric(c(vb)) || !is.character(filename) )
+     if ( FALSE %in% is.integer(c(it)) || FALSE %in% is.numeric(c(vb)) || !is.character(filename))
          stop("Please provide sensible arguments!")
     filename <- paste(filename,".ply",sep="")
     if (!is.null(mesh$material$color) && writeCol==TRUE) {
@@ -42,3 +48,15 @@ vcgPlyWrite <- function(mesh, filename=dataname, binary = TRUE, addNormals = FAL
     
     tmp <- .Call("RPlyWrite", vb, it , binary, addNormals, filename, colvec, hasCol)
 }
+
+#' @rdname vcgPlyWrite
+#' @export
+vcgPlyWrite.matrix <- function(mesh,filename=dataname, binary = TRUE, ...) {
+    dataname <- deparse(substitute(mesh))
+    filename <- path.expand(as.character(filename))
+    mm <- list()
+    mm$vb <- t(mesh)
+    class(mm) <- "mesh3d"
+    vcgPlyWrite(mm,filename=filename,binary =binary)
+}
+    
