@@ -35,6 +35,9 @@
 #include <wrap/io_trimesh/export_ply.h>
 #include <vcg/complex/algorithms/update/color.h>
 //#include <vcg/complex/algorithms/update/curvature.h>
+#ifndef RcppExport
+#define RcppExport extern "C"
+#endif
 
 using namespace vcg;
 //using namespace std;
@@ -43,41 +46,43 @@ class MyFace;
 class MyEdge;
 class MyVertex;
 struct MyUsedTypes: public UsedTypes<Use<MyVertex>::AsVertexType,
-                                     Use<MyEdge>::AsEdgeType,
-                                     Use<MyFace>::AsFaceType
-                                     >{};
+  Use<MyEdge>::AsEdgeType,
+  Use<MyFace>::AsFaceType
+  >{};
 
 class MyEdge : public Edge<MyUsedTypes>{};
 class MyVertex  : public Vertex< MyUsedTypes, 
-		  //vertex::InfoOcf,
-                                 vertex::Coord3f, 
-                                 vertex::BitFlags, 
-                                 vertex::Normal3f, 
-                                 vertex::Mark,
-                                 vertex::Color4b, 
-                                 vertex::Qualityf,
-		  /* vertex::VFAdjOcf,
-		     vertex::CurvaturefOcf,
-		     vertex::CurvatureDirfOcf,*/
-                                 vertex::VFAdj,
-                                 vertex::Curvaturef,
-                                 vertex::CurvatureDirf
-				 >{};
+  vertex::InfoOcf,
+  vertex::Coord3f, 
+  vertex::BitFlags, 
+  vertex::Normal3f, 
+  vertex::Mark,
+  vertex::Color4bOcf, 
+  vertex::QualityfOcf,
+  vertex::VFAdjOcf,
+  vertex::CurvaturefOcf,
+  vertex::CurvatureDirfOcf
+  /*vertex::VFAdj,
+    vertex::Curvaturef,
+    vertex::CurvatureDirf*/
+  >{};
 class MyFace: public Face  <MyUsedTypes, 
-	      //face::InfoOcf,
-                                face::VFAdj,
-                                face::VertexRef,
-                                face::BitFlags,
-                                face::Mark,
-	      //face::FFAdjOcf, 
-                                face::FFAdj, 
-                                face::Normal3f> {};
+  face::InfoOcf,
+  face::VertexRef,
+  face::BitFlags,
+  face::Mark,
+  face::FFAdjOcf, 
+  face::VFAdjOcf, 
+  face::Normal3fOcf
+  /*face::FFAdj, 
+    face::VFAdj,*/
+  > {};
 
 
 // ocf class
-//class MyMesh : public vcg::tri::TriMesh< vcg::vertex::vector_ocf<MyVertex>, vcg::face::vector_ocf<MyFace > >{};
+class MyMesh : public vcg::tri::TriMesh< vcg::vertex::vector_ocf<MyVertex>, vcg::face::vector_ocf<MyFace > >{};
 // default class
-class MyMesh : public vcg::tri::TriMesh< std::vector<MyVertex>, std::vector<MyFace > >{};
+//class MyMesh : public vcg::tri::TriMesh< std::vector<MyVertex>, std::vector<MyFace > >{};
 typedef  MyMesh::ScalarType ScalarType;
 typedef  MyMesh::VertexIterator VertexIterator;
 typedef  MyMesh::VertexPointer VertexPointer;
